/*
 * Sixth 3D engine. Author: Svjatoslav Agejenko. 
 * This project is released under Creative Commons Zero (CC0) license.
 */
package eu.svjatoslav.sixth.e3d.renderer.raster.shapes;

import eu.svjatoslav.sixth.e3d.geometry.Point3D;
import eu.svjatoslav.sixth.e3d.gui.RenderingContext;
import eu.svjatoslav.sixth.e3d.math.TransformsStack;
import eu.svjatoslav.sixth.e3d.math.Vertex;
import eu.svjatoslav.sixth.e3d.renderer.raster.RenderAggregator;

import java.util.concurrent.atomic.AtomicInteger;

public abstract class AbstractCoordinateShape extends AbstractShape {

    private static final AtomicInteger lastShapeId = new AtomicInteger();
    public final int shapeId;
    public final Vertex[] coordinates;
    public double onScreenZ;

    public AbstractCoordinateShape(final int pointsCount) {
        coordinates = new Vertex[pointsCount];
        for (int i = 0; i < pointsCount; i++)
            coordinates[i] = new Vertex();

        shapeId = lastShapeId.getAndIncrement();
    }

    public AbstractCoordinateShape(final Point3D... vertexes) {
        coordinates = new Vertex[vertexes.length];

        for (int i = 0; i < vertexes.length; i++)
            coordinates[i] = new Vertex(vertexes[i]);

        shapeId = lastShapeId.getAndIncrement();
    }

    public double getZ() {
        return onScreenZ;
    }

    public abstract void paint(RenderingContext renderBuffer);

    @Override
    public void transform(final TransformsStack transforms,
                          final RenderAggregator aggregator,
                          final RenderingContext renderingContext) {

        double accumulatedZ = 0;
        boolean paint = true;

        for (final Vertex geometryPoint : coordinates) {
            geometryPoint.calculateLocationRelativeToViewer(transforms, renderingContext);

            accumulatedZ += geometryPoint.transformedCoordinate.z;

            if (!geometryPoint.transformedCoordinate.isVisible())
                paint = false;
        }

        if (paint) {
            onScreenZ = accumulatedZ / coordinates.length;
            aggregator.queueShapeForRendering(this);
        }
    }

}
